# Summary of 1 files

## KnownCorruptedFile

```
Error in <TBranchElement::GetBasket>: File: root://proxy@xrootd.grid.surfsara.nl//pnfs/grid.sara.nl/data/lhcb/LHCb-Disk/lhcb/LHCb/Collision18/DIMUON.DST/00075559/0001/00075559_00017779_1.dimuon.dst at byte:511610300, branch:_Event_pRec_Track_Best., entry:5433, badread=1, nerrors=10, basketnumber=1280

```

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) |
| --------- | --- | ------ | ---- | -------- | ---------- |
| `249768` | `LFN:/lhcb/LHCb/Collision18/DIMUON.DST/00075559/0001/00075559_00017779_1.dimuon.dst` | 966761259 | LCG.SARA.nl | 15.3 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FLHCb%2FCollision18%2FLOG%2F00249768%2F0000&task_name=00001235) |
